package WQS::SPARQL::Query;

use strict;
use warnings;

our $VERSION = 0.02;

1;

__END__

=pod

=encoding utf8

=head1 NAME

WQS::SPARQL::Query - Useful Wikdata Query Service SPARQL queries.

=head1 SEE ALSO

=over

=item L<WQS::SPARQL::Query::Count>

Simple SPARQL count query.

=item L<WQS::SPARQL::Query::Select>

Simple SPARQL select query.

=back

=head1 REPOSITORY

L<https://github.com/michal-josef-spacek/WQS-SPARQL-Query>

=head1 AUTHOR

Michal Josef Špaček L<mailto:skim@cpan.org>

L<http://skim.cz>

=head1 LICENSE AND COPYRIGHT

© 2020-2024 Michal Josef Špaček

BSD 2-Clause License

=head1 VERSION

0.02

=cut
